/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.orkut.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.util.DateTime;

/**
 * Model definition for Comment.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Orkut API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Comment extends GenericJson {

  /**
   * The person who posted the comment.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private OrkutAuthorResource actor;

  /**
   * The content of the comment in text/html
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String content;

  /**
   * The unique ID for the comment.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * Link to the original activity where this comment was posted.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private InReplyTo inReplyTo;

  /**
   * Identifies this resource as a comment. Value: "orkut#comment"
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * List of resources for the comment.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<OrkutLinkResource> links;

  static {
    // hack to force ProGuard to consider OrkutLinkResource used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(OrkutLinkResource.class);
  }

  /**
   * The time the comment was initially published, in RFC 3339 format.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime published;

  /**
   * The person who posted the comment.
   * The value returned may be {@code null}.
   */
  public OrkutAuthorResource getActor() {
    return actor;
  }

  /**
   * The person who posted the comment.
   * The value set may be {@code null}.
   */
  public Comment setActor(OrkutAuthorResource actor) {
    this.actor = actor;
    return this;
  }

  /**
   * The content of the comment in text/html
   * The value returned may be {@code null}.
   */
  public String getContent() {
    return content;
  }

  /**
   * The content of the comment in text/html
   * The value set may be {@code null}.
   */
  public Comment setContent(String content) {
    this.content = content;
    return this;
  }

  /**
   * The unique ID for the comment.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * The unique ID for the comment.
   * The value set may be {@code null}.
   */
  public Comment setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * Link to the original activity where this comment was posted.
   * The value returned may be {@code null}.
   */
  public InReplyTo getInReplyTo() {
    return inReplyTo;
  }

  /**
   * Link to the original activity where this comment was posted.
   * The value set may be {@code null}.
   */
  public Comment setInReplyTo(InReplyTo inReplyTo) {
    this.inReplyTo = inReplyTo;
    return this;
  }

  /**
   * Identifies this resource as a comment. Value: "orkut#comment"
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Identifies this resource as a comment. Value: "orkut#comment"
   * The value set may be {@code null}.
   */
  public Comment setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * List of resources for the comment.
   * The value returned may be {@code null}.
   */
  public java.util.List<OrkutLinkResource> getLinks() {
    return links;
  }

  /**
   * List of resources for the comment.
   * The value set may be {@code null}.
   */
  public Comment setLinks(java.util.List<OrkutLinkResource> links) {
    this.links = links;
    return this;
  }

  /**
   * The time the comment was initially published, in RFC 3339 format.
   * The value returned may be {@code null}.
   */
  public DateTime getPublished() {
    return published;
  }

  /**
   * The time the comment was initially published, in RFC 3339 format.
   * The value set may be {@code null}.
   */
  public Comment setPublished(DateTime published) {
    this.published = published;
    return this;
  }

  /**
   * Link to the original activity where this comment was posted.
   */
  public static final class InReplyTo extends GenericJson {

    /**
     * Link to the post on activity stream being commented.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String href;

    /**
     * Unique identifier of the post on activity stream being commented.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String ref;

    /**
     * Relationship between the comment and the post on activity stream being commented. Always
     * inReplyTo.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String rel;

    /**
     * Type of the post on activity stream being commented. Always text/html.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String type;

    /**
     * Link to the post on activity stream being commented.
     * The value returned may be {@code null}.
     */
    public String getHref() {
      return href;
    }

    /**
     * Link to the post on activity stream being commented.
     * The value set may be {@code null}.
     */
    public InReplyTo setHref(String href) {
      this.href = href;
      return this;
    }

    /**
     * Unique identifier of the post on activity stream being commented.
     * The value returned may be {@code null}.
     */
    public String getRef() {
      return ref;
    }

    /**
     * Unique identifier of the post on activity stream being commented.
     * The value set may be {@code null}.
     */
    public InReplyTo setRef(String ref) {
      this.ref = ref;
      return this;
    }

    /**
     * Relationship between the comment and the post on activity stream being commented. Always
     * inReplyTo.
     * The value returned may be {@code null}.
     */
    public String getRel() {
      return rel;
    }

    /**
     * Relationship between the comment and the post on activity stream being commented. Always
     * inReplyTo.
     * The value set may be {@code null}.
     */
    public InReplyTo setRel(String rel) {
      this.rel = rel;
      return this;
    }

    /**
     * Type of the post on activity stream being commented. Always text/html.
     * The value returned may be {@code null}.
     */
    public String getType() {
      return type;
    }

    /**
     * Type of the post on activity stream being commented. Always text/html.
     * The value set may be {@code null}.
     */
    public InReplyTo setType(String type) {
      this.type = type;
      return this;
    }

  }

}
